@@ -12,7 +12,6 @@ from CRTK.utilities import opcode_occurrence
 class Contract(object):
     def __init__(self):
         # contract type
-        self.runtime_contract = False
         self.real_contract = False
 
         # contract standard
@@ -51,8 +50,5 @@ class Contract(object):
     def is_ERC777(self):
         return self.ERC777
 
-    def is_runtime_contract(self):
-        return self.runtime_contract
-
     def is_real_contract(self):
         return self.real_contract
