@@ -291,13 +291,13 @@ def signature_to_function(function_signature):
 
     There might be several query results if hash collision encountered and also might be no result due to data vacancy.
     '''
-    dir_list = os.listdir('../')
+    dir_list = os.listdir('./')
     if not 'Function-Signatures' in dir_list:
         import subprocess
-        subprocess.run(['git', 'clone', 'https://github.com/yzstr/Function-Signatures.git', '../Function-Signatures'])
+        subprocess.run(['git', 'clone', 'https://github.com/yzstr/Function-Signatures.git'])
     
     import csv
-    with open('../Function-Signatures/Function-Signature.csv','r') as f:
+    with open('./Function-Signatures/Function-Signature.csv','r') as f:
         reader = csv.reader(f)
         res = [line[0] for line in reader if line[1] == function_signature]
     return res
\ No newline at end of file
